// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KDEVPHP_VERSION_H
#define KDEVPHP_VERSION_H

#define KDEVPHP_VERSION_STRING "5.7.220403"
#define KDEVPHP_VERSION_MAJOR 5
#define KDEVPHP_VERSION_MINOR 7
#define KDEVPHP_VERSION_PATCH 220403
#define KDEVPHP_VERSION ((5<<16)|(7<<8)|(220403))

#endif
